      subroutine user_evt1
c
c user pass 1 event routine
c
c this example user_evt1 routine, for each event, does the 
c following:
c - print the adc value from the selected channel
c - obtain the signal(adc - pedestal) of the selected channel
c   using the 3 available adc channel addressing systems
c - obtain the signal(adc - pedestal) of a cluster made of the
c   selected channel and the one above in eta
c - fill the user ntuple with the signals
c - accumulate the moments for the first time sampling 
c   pedestal covariance computation
c
      implicit none
c
c shared parameters common
c general constants
c please read the comment in the *.inc file
c
      include'hec_par.inc'
c
c adc values common
c this is where the adc values 
c are stored, for different adc channel addressing systems
c must be preceded by the include file hec_par.inc
c please read the comment in the *.inc file
c
      include'hec_adc.inc'
c
c geometry correspondence tables common
c this is an important file, with lots of important comments on
c the adc channel addressing schemes.
c must be preceded by the include file hec_par.inc
c please read the comment in the *.inc file
c
      include'hec_geo.inc'
c
c max adc and time values common
c this is where the max adc and corresponding time values 
c are stored, for different adc channel addressing systems
c must be preceded by the include file hec_par.inc
c please read the comment in the *.inc file
c
      include'hec_max.inc'
c
c pedestal values common
c must be preceded by the include file hec_par.inc
c please read the comment in the *.inc file
c
      include'hec_ped.inc'
c
c event trigger common
c user friendly trigger logical variables
c please read the comment in the *.inc file
c 
      include'hec_trig.inc'
c
c user datacard values common
c this is where the user datacard values endup after the 
c initialisation phase has read the datacards
c please read the comment in the *.inc file
c
      include'user_datacard.inc'
c
c user internal variables common
c this is where are the variables used to compute the pedestal
c variance between the picked channel and the one above in eta
c
      include'user_common.inc'
c
c local variable declarations
c 
      real sigic, sigdb, sigph, sigcl
      real sigph_b
      integer ic, i_mod, i_seg, i_pad, i_eta , i_phi ,i_z
      integer ic_b
      real x(4)
c
c user code
c
c get the picked channel from the user datacard values common
c ic_pick does not change from event to event, so the following
c is mainly pedagogical...
c
      ic = ic_pick
c
c get the database system coordinates of the selected channel
c
      i_mod = ictodb(ic, 1)
      i_seg = ictodb(ic, 2)
      i_pad = ictodb(ic, 3)
c
c get the physics system coordinates of the selected channel
c
      i_eta = ictoph(ic, 1)
      i_phi = ictoph(ic, 2)
      i_z   = ictoph(ic, 3)
c
c print the adc(max) value of the selected channel, obtained from
c the adc(max) arrays in the 3 addressing systems available
c they should all be the same!
c
      print *, 'ic = ', ic, 
     +         '    adc = ', adc_max_ic(ic, 1),
     +                       adc_max_db(i_mod, i_seg, i_pad, 1),
     +                       adc_max_ph(i_eta, i_phi, i_z, 1)
c
c for physics trigger only,
c obtain the signal(adc - pedestal) for the selected channel
c again using the 3 addressing systems available
c
      if (trig_physics) then
        sigic = adc_max_ic(ic, 1) - adc_ped(ic)
        sigdb = adc_max_db(i_mod, i_seg, i_pad, 1) - adc_ped(ic)
        sigph = adc_max_ph(i_eta, i_phi, i_z, 1) - adc_ped(ic)
c
c obtain the signal(adc - pedestal) for a cluster made of the 
c selected channel and the one above in eta
c
        sigcl = sigic
        if (i_eta + 1 .le. i_eta_used) then
          ic_b = phtoic(i_eta + 1, i_phi, i_z)
          sigph_b = adc_max_ic(ic_b, 1) - adc_ped(ic_b)
          sigcl = sigcl + sigph_b
        endif
c
c fill the ntuple 
c note that if all is ok, then sigic=sigdb=sigph !
c
        x(1) = sigic
        x(2) = sigdb
        x(3) = sigph
        x(4) = sigcl
        call hfn(1, x)
      endif
c
c accumulate the first time sampling signal (pedestal) moments
c needed to compute the covariance of the one time sampling 
c pedestal value between the two channels in the cluster
c
      if (i_eta + 1 .le. i_eta_used) then
        ic_b = phtoic(i_eta + 1, i_phi, i_z)
        m_0   = m_0   + 1
        dm_1a  = dm_1a  + i_adc_ic_t(ic, 1)
        dm_1b  = dm_1b  + i_adc_ic_t(ic_b, 1)
        dm_2ab = dm_2ab + i_adc_ic_t(ic, 1)*i_adc_ic_t(ic_b, 1)
      endif
c
      end







