***********************************************************************
*       Program call the reading routine, which reads the binary file
*       with calibration data and store them in the common
*
***********************************************************************
        program cal_example

        integer ihead, maxchannels, maxdelays
        integer idelay
        real mean, sigma

        parameter (maxchannels = 48,
     *             maxdelays = 12,
     *             maxslices = 252)

        common/header/ ihead(9)
***********************************************************************
*       Header contains:
*                        ihead(1) - number of events in runs
*                        ihead(2) - number of slices read per FADC
*                        ihead(3) - number of FADC's
*                        ihead(4) - DAC value pulsed
*                        ihead(5) - hardware offset in FADC buffer
*                        ihead(6) - Delay register used in delay scan
*                        ihead(7) - number of first slice written in file
*                        ihead(8) - number of slices per FADC written in file
*                        ihead(9) - reserved
***********************************************************************

        common/data/mean(maxdelays, maxchannels, maxslices),
     *              sigma(maxdelays, maxchannels, maxslices) 
***********************************************************************
*       mean contains FADC mean values,
*             first index go on delays
*             second go on FADC's
*             third go on  slices of FADC
*       sigma contains errors with same indexes
***********************************************************************
        
        common/delays/idelay(maxdelays)
***********************************************************************
*       idelay contains the values of delay of calibration pulse
***********************************************************************


        call calread('input.dat', istat)
        if(istat.eq.0) then
          print *, 'Reading done succesfully'
        else
          print *, 'An error ',istat,' occured'
        endif

        stop
        end
***********************************************************************



***********************************************************************
***********************************************************************
*       Subroutine calread  created 10.6.1997 by P. Strizenec
*       Syntax:
*       calread(filname, istat)
*
*       Parameters:
*               filname - string with input file name
*               istat   - return error status of reading
*                       - 0 no errors
*                       - -1 error in opening input file
*                       - -2 error while reading data
*                       - -3 internal error in calread (should never be)
*
*       So far working fine on HP-UX and AIX on RS/6000
***********************************************************************

        subroutine calread(filename, istat)

*                                       Parameters declaration
        character*80 filename
        integer     istat
*                                       Local variables
        integer iostat
        integer i,num, numd, numrec
        integer ievt, ichan, isli
        integer*2   word
        real iwork
        real swork
        logical go

*                                       Commons and variables for them
        integer ihead, maxchannels, maxdelays
        integer idelay
        real mean, sigma

        parameter (num=1)
      
        parameter (maxchannels = 48,
     *             maxdelays = 12,
     *             maxslices = 252)

        common/header/ ihead(9)
        common/data/mean(maxdelays, maxchannels, maxslices),
     *              sigma(maxdelays, maxchannels, maxslices)

        common/delays/idelay(maxdelays)

*                                       Working arrays

        dimension iwork(maxchannels, maxslices)
        dimension swork(maxchannels, maxslices)

***                                     Open input file
        open(unit=2
     *     ,file=filename
     *     ,access='DIRECT'
     *     ,form='UNFORMATTED'
     *     ,status='OLD'
     *     ,recl=2
     *     ,err=1000
     *      )

        numrec=1
        numd=1
        go=.TRUE.

***                                     Reading the header 
        do i=1,9

          read(unit=2
     *     ,iostat=iostat
     *     ,rec=numrec
     *     ,err=2000
     *        )  word
          ihead(i)=word
          numrec=numrec+1
        enddo



***                                     Start loop over delays

        do while(go)
          read(unit=2, iostat=iostat, rec=numrec)  word
          if(iostat.ne.0) then
            close(2)
            print *, numd-1,' delays read'
            istat = 0
            return
          endif
          numrec = numrec + 1
          idelay(numd)=word

***                                     Clearing the working arrays
          do ichan=1, ihead(3)
            do isli=1, ihead(2)
                iwork(ichan, isli) = 0.
                swork(ichan, isli) = 0.
            enddo
          enddo
***                                     Start loop over events

          do ievt=1, ihead(1)

***                                     Start loop over FADC's
            do ichan=1, ihead(3)

***                                     Start loop over slices
                do isli=1, ihead(2)
                  read(unit=2, iostat=iostat, rec=numrec)  word
***                                     If error
                  if(iostat.ne.0) then
                        print *, 'Error occured while reading the'
                        print *, numd,'-th delay'
                        print *, ievt,'-th event'
                        print *, ichan,'-th FADC'
                        print *, isli,'-th slice'
                        istat = -2
                        return
                  endif

                  iwork(ichan, isli) = iwork(ichan, isli) + word
                  swork(ichan, isli) = swork(ichan, isli) + word**2
                  numrec=numrec+1
                enddo
            enddo
          enddo
        
***                                     Compute means and sigmas on this delay
          do ichan=1, ihead(3)
            do isli=1, ihead(2)
                mean(numd, ichan, isli) = iwork(ichan, isli)/ihead(1) 
                sigma(numd, ichan, isli) = swork(ichan, isli)/ihead(1) -
     *                                     mean(numd, ichan, isli)**2 
            enddo
          enddo 
***                                     End of loop over delays
          numd=numd+1
        enddo
        istat = -3
        return

1000    print *, 'Error in opening file: ', filename 
        istat = -1
        return

2000    print *, 'Error in reading ',i,'-th header word'
        istat = -2
        return

3000    print *, 'Error in reading ',numd,'-th delay'
        istat = -2
        return

        end

